aboutsummaryrefslogtreecommitdiffstats
path: root/python_openapi_client/fatcat_openapi_client/models/editgroup_annotation.py
diff options
context:
space:
mode:
Diffstat (limited to 'python_openapi_client/fatcat_openapi_client/models/editgroup_annotation.py')
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/editgroup_annotation.py37
1 files changed, 17 insertions, 20 deletions
diff --git a/python_openapi_client/fatcat_openapi_client/models/editgroup_annotation.py b/python_openapi_client/fatcat_openapi_client/models/editgroup_annotation.py
index 5f648a92..81868060 100644
--- a/python_openapi_client/fatcat_openapi_client/models/editgroup_annotation.py
+++ b/python_openapi_client/fatcat_openapi_client/models/editgroup_annotation.py
@@ -5,9 +5,9 @@
Fatcat is a scalable, versioned, API-oriented catalog of bibliographic entities and file metadata. # noqa: E501
- OpenAPI spec version: 0.3.1
+ The version of the OpenAPI document: 0.3.1
Contact: webservices@archive.org
- Generated by: https://github.com/swagger-api/swagger-codegen.git
+ Generated by: https://openapi-generator.tech
"""
@@ -16,30 +16,29 @@ import re # noqa: F401
import six
-from fatcat_openapi_client.models.editor import Editor # noqa: F401,E501
-
class EditgroupAnnotation(object):
- """NOTE: This class is auto generated by the swagger code generator program.
+ """NOTE: This class is auto generated by OpenAPI Generator.
+ Ref: https://openapi-generator.tech
Do not edit the class manually.
"""
"""
Attributes:
swagger_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name
and the value is json key in definition.
"""
- swagger_types = {
+ openapi_types = {
'annotation_id': 'str',
'editgroup_id': 'str',
'editor_id': 'str',
'editor': 'Editor',
'created': 'datetime',
'comment_markdown': 'str',
- 'extra': 'object'
+ 'extra': 'dict(str, object)'
}
attribute_map = {
@@ -53,7 +52,7 @@ class EditgroupAnnotation(object):
}
def __init__(self, annotation_id=None, editgroup_id=None, editor_id=None, editor=None, created=None, comment_markdown=None, extra=None): # noqa: E501
- """EditgroupAnnotation - a model defined in Swagger""" # noqa: E501
+ """EditgroupAnnotation - a model defined in OpenAPI""" # noqa: E501
self._annotation_id = None
self._editgroup_id = None
@@ -103,8 +102,8 @@ class EditgroupAnnotation(object):
raise ValueError("Invalid value for `annotation_id`, length must be less than or equal to `36`") # noqa: E501
if annotation_id is not None and len(annotation_id) < 36:
raise ValueError("Invalid value for `annotation_id`, length must be greater than or equal to `36`") # noqa: E501
- if annotation_id is not None and not re.search('[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', annotation_id): # noqa: E501
- raise ValueError("Invalid value for `annotation_id`, must be a follow pattern or equal to `/[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}/`") # noqa: E501
+ if annotation_id is not None and not re.search(r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}', annotation_id): # noqa: E501
+ raise ValueError(r"Invalid value for `annotation_id`, must be a follow pattern or equal to `/[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}/`") # noqa: E501
self._annotation_id = annotation_id
@@ -132,8 +131,8 @@ class EditgroupAnnotation(object):
raise ValueError("Invalid value for `editgroup_id`, length must be less than or equal to `26`") # noqa: E501
if editgroup_id is not None and len(editgroup_id) < 26:
raise ValueError("Invalid value for `editgroup_id`, length must be greater than or equal to `26`") # noqa: E501
- if editgroup_id is not None and not re.search('[a-zA-Z2-7]{26}', editgroup_id): # noqa: E501
- raise ValueError("Invalid value for `editgroup_id`, must be a follow pattern or equal to `/[a-zA-Z2-7]{26}/`") # noqa: E501
+ if editgroup_id is not None and not re.search(r'[a-zA-Z2-7]{26}', editgroup_id): # noqa: E501
+ raise ValueError(r"Invalid value for `editgroup_id`, must be a follow pattern or equal to `/[a-zA-Z2-7]{26}/`") # noqa: E501
self._editgroup_id = editgroup_id
@@ -161,8 +160,8 @@ class EditgroupAnnotation(object):
raise ValueError("Invalid value for `editor_id`, length must be less than or equal to `26`") # noqa: E501
if editor_id is not None and len(editor_id) < 26:
raise ValueError("Invalid value for `editor_id`, length must be greater than or equal to `26`") # noqa: E501
- if editor_id is not None and not re.search('[a-zA-Z2-7]{26}', editor_id): # noqa: E501
- raise ValueError("Invalid value for `editor_id`, must be a follow pattern or equal to `/[a-zA-Z2-7]{26}/`") # noqa: E501
+ if editor_id is not None and not re.search(r'[a-zA-Z2-7]{26}', editor_id): # noqa: E501
+ raise ValueError(r"Invalid value for `editor_id`, must be a follow pattern or equal to `/[a-zA-Z2-7]{26}/`") # noqa: E501
self._editor_id = editor_id
@@ -170,7 +169,6 @@ class EditgroupAnnotation(object):
def editor(self):
"""Gets the editor of this EditgroupAnnotation. # noqa: E501
- Only included in GET responses; ignored in PUT or POST requests. # noqa: E501
:return: The editor of this EditgroupAnnotation. # noqa: E501
:rtype: Editor
@@ -181,7 +179,6 @@ class EditgroupAnnotation(object):
def editor(self, editor):
"""Sets the editor of this EditgroupAnnotation.
- Only included in GET responses; ignored in PUT or POST requests. # noqa: E501
:param editor: The editor of this EditgroupAnnotation. # noqa: E501
:type: Editor
@@ -240,7 +237,7 @@ class EditgroupAnnotation(object):
Additional free-form JSON metadata that can be included as part of the annotation (or even as the primary annotation itself). See guide for details. # noqa: E501
:return: The extra of this EditgroupAnnotation. # noqa: E501
- :rtype: object
+ :rtype: dict(str, object)
"""
return self._extra
@@ -251,7 +248,7 @@ class EditgroupAnnotation(object):
Additional free-form JSON metadata that can be included as part of the annotation (or even as the primary annotation itself). See guide for details. # noqa: E501
:param extra: The extra of this EditgroupAnnotation. # noqa: E501
- :type: object
+ :type: dict(str, object)
"""
self._extra = extra
@@ -260,7 +257,7 @@ class EditgroupAnnotation(object):
"""Returns the model properties as a dict"""
result = {}
- for attr, _ in six.iteritems(self.swagger_types):
+ for attr, _ in six.iteritems(self.openapi_types):
value = getattr(self, attr)
if isinstance(value, list):
result[attr] = list(map(
@@ -16,30 +16,29 @@ import re # noqa: F401
"""
Attributes:
- swagger_types (dict): The key is attribute name
+ openapi_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name